/************************************************************
 *
 * COPYRIGHT (C) HITACHI,LTD. 2003-2004
 * WRITTEN BY HITACHI SYSTEMS DEVELOPMENT LABORATORY,
 *            HITACHI CENTRAL RESEARCH LABORATORY.
 *
 * Created by M.Hiramatsu <hiramatu@sdl.hitachi.co.jp>
 *
 ************************************************************/

/* Architecture independant events */
/* Do not check double (or more) including.
 This file will be included many times.*/

#ifndef LKST_ETYPE_DEF
#define LKST_ETYPE_DEF_NOT_DEFINED
#define LKST_ETYPE_DEF(event_type, hooktype, mnemonic, event_name, arg_1, arg_2, arg_3, arg_4)
#endif

/* Body of definitions of event types */
    /* Syntax:
        LKST_ETYPE_DEF(
            VALUE_OF_THE_EVENT_TYPE:(0x001..0xffe),
            TYPE OF GKHI HOOK HEADER,
            MNEMONIC_OF_THE_EVENT_TYPE,
            EVENT_NAME_STRING,
            EVENT_ARG1_STRING,
            EVENT_ARG2_STRING,
            EVENT_ARG3_STRING,
            EVENT_ARG4_STRING ) */

//0x001 event
LKST_ETYPE_DEF(0x001, NORMAL, PROCESS_CONTEXTSWITCH, "context_switch", \
	"pointer to task_struct prev ", \
	"pointer to task_struct next ", \
	"process state", \
	"nr_running")

//0x002 event
LKST_ETYPE_DEF(0x002, NORMAL, PROCESS_WAKEUP, "process_wakeup", \
	"pointer to wakeup-process p ", \
	"process state", \
	"synchronus", \
	NULL)

//0x003 event
LKST_ETYPE_DEF(0x003, NORMAL, PROCESS_SIGSEND, "process_sigsend", \
	"signal number sig ", \
	"pointer to process to which signal is sent", \
	"pointer to info structure info ", \
	NULL)

/* lthreadgen event(0x004) is defined in asm/lkst_etype.h */

//0x005 event
LKST_ETYPE_DEF(0x005, INLINE, PROCESS_INIT_WQH, "process_init_waitq_head", \
	"pointer to wait_queue_head", \
	"pointer to call address", \
	NULL, \
	NULL)

//0x006 event
LKST_ETYPE_DEF(0x006, INLINE, PROCESS_ADD_WQ, "process_add_waitq", \
	"pointer to wait_queue_head", \
	"pointer to added process", \
	"pointer to call address", \
	NULL)

//0x007 event
LKST_ETYPE_DEF(0x007, INLINE, PROCESS_REM_WQ, "process_remove_waitq", \
	"pointer to wait_queue_head", \
	"pointer to removed process", \
	"pointer to call address", \
	NULL)

LKST_ETYPE_DEF(0x008, NORMAL, PROCESS_SCHED_ENTER, "enter scheduler", \
	       "current", \
	       "nr_running",\
	       "comm1",\
	       "comm2")
LKST_ETYPE_DEF(0x009, NORMAL, PROCESS_SCHED_EXIT, "exit scheduler", \
	       "current", \
	       "next",\
	       NULL,\
	       NULL)
LKST_ETYPE_DEF(0x00a, NORMAL, PROCESS_FORK, "do_fork", \
	       "forked pid", \
	       "task struct",\
	       "clone flags",\
	       "process state")
LKST_ETYPE_DEF(0x00b, NORMAL, PROCESS_EXIT, "do_exit", \
	       "exit pid", \
	       "exit code",\
	       NULL,\
	       NULL)

/* hwintr event(0x010) is defined in asm/lkst_etype.h */

//0x012 event
LKST_ETYPE_DEF(0x012, NORMAL, INT_TASKLETHI_ENTRY, "interrupt_tasklethi_entry", \
	"action address t->func ", \
	NULL, \
	NULL, \
	NULL)

//0x014 event
LKST_ETYPE_DEF(0x014, NORMAL, INT_TASKLET_ENTRY, "interrupt_tasklet_entry", \
	"action address t->func ", \
	NULL, \
	NULL, \
	NULL)
     
//0x016 event
LKST_ETYPE_DEF(0x016, NORMAL, INT_BH_ENTRY, "interrupt_bh_entry", \
	       "interrupt type nr ", \
	       "action address bh_base ", \
	       NULL, \
	       NULL)

//0x018 event
LKST_ETYPE_DEF(0x018, INLINE, SOFTIRQ_RAISE, "software IRQ request", \
	       "softirq nr ", \
	       NULL, \
	       NULL, \
	       NULL)

//0x019 event
LKST_ETYPE_DEF(0x019, NORMAL, SOFTIRQ_ACTION, "software IRQ action", \
	       "softirq nr ", \
	       NULL, \
	       NULL, \
	       NULL)

/* exception events(0x02*) are defined in asm/lkst_etype.h */

/* syscall events(0x03*) are defined in asm/lkst_etype.h */

/* FS events are currently disabled.
//0x040 event
LKST_ETYPE_DEF(0x040, NORMAL, FS_DEVRW,"fs_devrw",\
        "buffer(bh)", \
        "READ/WRITE(rw)", \
        "the number of block transfered(nr)", \
         NULL)
LKST_ETYPE_DEF(0x041, NORMAL, FS_DEVEND,"fs_devend",\
        "buffer(bf)", \
        "uptodate", \
         NULL, \
         NULL)
LKST_ETYPE_DEF(0x042, NORMAL, FS_BUFBUSY, "fs_devwait",\
        "buffer(bh)", \
         NULL,\
         NULL,\
         NULL)
*/

LKST_ETYPE_DEF(0x050, NORMAL, MEM_SWAPOUT, "mem_swapout", \
	"pointer to page swapped-out", \
	NULL, \
	NULL, \
	NULL)
LKST_ETYPE_DEF(0x051, NORMAL, MEM_SWAPIN, "mem_swapin", \
	"pointer to page swapped-in", \
	NULL, \
	NULL, \
	NULL)

//0x052 event
LKST_ETYPE_DEF(0x052, NORMAL, MEM_DO_NOPAGE, "mem_do_nopage", \
	"pointer to page allocated", \
	NULL, \
	NULL, \
	NULL)

//0x053 event
LKST_ETYPE_DEF(0x053, NORMAL, MEM_DO_WPPAGE, "mem_do_wppage", \
	"pointer to page", \
	NULL, \
	NULL, \
	NULL)

//0x054 event
LKST_ETYPE_DEF(0x054, INLINE, MEM_WAIT_PAGE, "mem_wait_page", \
	"pointer to page", \
	NULL, \
	NULL, \
	NULL)

//0x055 event
LKST_ETYPE_DEF(0x055, NORMAL, MEM_GET_FREEPAGE, "mem_get_freepage", \
	"pointer to page", \
	"type of page gfp_mask ", \
	"the number of page order ", \
	"call address")

//0x056 event
LKST_ETYPE_DEF(0x056, NORMAL, MEM_GET_ZEROPAGE, "mem_get_zeropage", \
	"pointer to page", \
	"type of page gfp_mask ", \
	"call address", \
	NULL)

//0x057 event
LKST_ETYPE_DEF(0x057, NORMAL, MEM_FREEPAGE, "mem_freepage", \
	"pointer to page", \
	"the number of page order ", \
	"call address", \
	NULL)

//0x058 event
LKST_ETYPE_DEF(0x058, INLINE, MEM_VMALLOC, "mem_vmalloc", \
	"address addr ", \
	"size", \
	"call address", \
	NULL)

//0x059 event
LKST_ETYPE_DEF(0x059, NORMAL, MEM_VFREE, "mem_vfree", \
	"address addr ", \
	NULL, \
	NULL, \
	NULL)

//0x05a event
LKST_ETYPE_DEF(0x05a, NORMAL, MEM_CACHE_CREATE, "mem_cache_create", \
	"name", \
	"size", \
	"cachep", \
	NULL)

//0x05b event
LKST_ETYPE_DEF(0x05b, NORMAL, MEM_CACHE_ALLOC, "mem_cache_alloc", \
	"cachep", \
	"flags", \
	"objp", \
	"call address")

//0x05c event
LKST_ETYPE_DEF(0x05c, NORMAL, MEM_MALLOC, "mem_malloc", \
	"size", \
	"flags", \
	"objp", \
	"call address")

//0x05d event
LKST_ETYPE_DEF(0x05d, NORMAL, MEM_CACHE_FREE, "mem_cache_free", \
	"cachep", \
	"objp", \
	"call address", \
	NULL)

//0x05e event
LKST_ETYPE_DEF(0x05e, NORMAL, MEM_FREE, "mem_free", \
	"objp", \
	"call address", \
	NULL, \
	NULL)

//0x060 event
LKST_ETYPE_DEF(0x060, NORMAL, NET_PKTSEND, "net_pktsend", \
	"skb", \
	NULL, \
	NULL, \
	NULL)

//0x061 event
LKST_ETYPE_DEF(0x061, NORMAL, NET_PKTSENDI, "net_pktsendi", \
	"h", \
	NULL, \
	NULL, \
	NULL)

//0x062 event
LKST_ETYPE_DEF(0x062, NORMAL, NET_PKTRECV, "net_pktrecv", \
	"skb", \
	NULL, \
	NULL, \
	NULL)

//0x063 event
LKST_ETYPE_DEF(0x063, NORMAL, NET_PKTRECVI, "net_pktrecvi", \
	"h", \
	NULL, \
	NULL, \
	NULL)

//0x064 event(socketcall) depends on arch. so, move to asm/lkst_etype.h

//0x070 event
LKST_ETYPE_DEF(0x070, NORMAL, SYSV_IPC_SEMOP, "sysv_ipc_semop", \
	"semid", \
	"tsops", \
	"nsops", \
	NULL)

//0x071 event
LKST_ETYPE_DEF(0x071, NORMAL, SYSV_IPC_SEMGET, "sysv_ipc_semget", \
	"key", \
	"nsems", \
	"semflg", \
	NULL)

//0x072 event
LKST_ETYPE_DEF(0x072, NORMAL, SYSV_IPC_SEMCTL, "sysv_ipc_semctl", \
	"semid", \
	"semnum", \
	"cmd", \
	"arg.__pad")

//0x073 event
LKST_ETYPE_DEF(0x073, NORMAL, SYSV_IPC_MSGSEND, "sysv_ipc_msgsend", \
	"msqid", \
	"msgp", \
	"msgsz", \
	"msgflg")

//0x074 event
LKST_ETYPE_DEF(0x074, NORMAL, SYSV_IPC_MSGRCV, "sysv_ipc_msgrcv", \
	"msqid/msgflg", \
	"msgp", \
	"msgsz", \
	"msgtyp")

//0x075 event
LKST_ETYPE_DEF(0x075, NORMAL, SYSV_IPC_MSGGET, "sysv_ipc_msgget", \
	"key", \
	"msgflg", \
	NULL, \
	NULL)

//0x076 event
LKST_ETYPE_DEF(0x076, NORMAL, SYSV_IPC_MSGCTL, "sysv_ipc_msgctl", \
	"msqid", \
	"cmd", \
	"buf", \
	NULL)

//0x077 event
LKST_ETYPE_DEF(0x077, NORMAL, SYSV_IPC_SHMAT, "sysv_ipc_shmat", \
	"shmid", \
	"shmaddr", \
	"shmflg", \
	"raddr")

//0x078 event
LKST_ETYPE_DEF(0x078, NORMAL, SYSV_IPC_SHMDT, "sysv_ipc_shmdt", \
	"shmaddr", \
	NULL, \
	NULL, \
	NULL)

//0x079 event
LKST_ETYPE_DEF(0x079, NORMAL, SYSV_IPC_SHMGET, "sysv_ipc_shmget", \
	"key", \
	"size", \
	"shmflg", \
	NULL)

//0x07a event
LKST_ETYPE_DEF(0x07a, NORMAL, SYSV_IPC_SHMCTL, "sysv_ipc_shmctl", \
	"shmid", \
	"cmd", \
	"buf", \
	NULL)

/*lock events(0x08*) are depend on the architecture */
/*io events(0x090/91) are depend on the architecture */

//0x092 event
LKST_ETYPE_DEF(0x092, NORMAL, O_PANIC, "panic", \
	"address of argument", \
	"call address", \
	NULL, \
	NULL)

//0x093 event
LKST_ETYPE_DEF(0x093, NORMAL, O_PRINTK, "printk", \
	"address of argument", \
	"call address", \
	NULL, \
	NULL)

//0x0a0 event
LKST_ETYPE_DEF(0x0a0, INLINE, TIMER_RUN, "timer_run", \
	"function address fn ", \
	"parameter data ", \
	"delayed time", \
	NULL)

//0x0a1 event
LKST_ETYPE_DEF(0x0a1, NORMAL, TIMER_ADD, "timer_add", \
	"timer", \
	"timer->expires", \
	"timer->function", \
	"timer->data")

//0x0a2 event
LKST_ETYPE_DEF(0x0a2, NORMAL, TIMER_MOD, "timer_mod", \
	"timer", \
	"timer->expires", \
	"timer->function", \
	"timer->data")

//0x0a3 event
LKST_ETYPE_DEF(0x0a3, NORMAL, TIMER_DEL, "timer_del", \
	"timer", \
	"timer->expires", \
	"timer->function", \
	"timer->data")
#ifdef CONFIG_SMP
LKST_ETYPE_DEF(0x0a4, NORMAL, TIMER_DEL_SYNC, "timer_del_sync", \
	"timer", \
	"timer->expires", \
	"timer->function", \
	"timer->data")
#endif /* CONFIG_SMP */

/*page allocation*/
LKST_ETYPE_DEF(0x0c0, NORMAL, PAGE_ALLOC_ENTER, "page_alloc_enter", \
	       "gfp_mask", \
	       "order", \
	       "zonelist", \
	       NULL)
LKST_ETYPE_DEF(0x0c1, NORMAL, PAGE_ALLOC_EXIT, "page_alloc_exit", \
	       "gfp_mask", \
	       "order", \
	       "zone", \
	       "pages")

/*shrinking*/
LKST_ETYPE_DEF(0x0c2, INLINE, SHRINK_SLAB_ENTER, "shrink_slab_enter", \
	       "scan", \
	       "gfp_mask", \
	       "lru_pages", \
	       NULL)
LKST_ETYPE_DEF(0x0c3, INLINE, SHRINK_SLAB_EXIT, "shrink_slab_exit", \
	       "scan", \
	       "gfp_mask", \
	       "lru_pages", \
	       "total_scanned")
LKST_ETYPE_DEF(0x0c4, NORMAL, SHRINK_CACHE_ENTER, "shrink_cache_enter", \
	       "zone", \
	       "scan control", \
	       "max_scan", \
	       NULL)
LKST_ETYPE_DEF(0x0c5, NORMAL, SHRINK_CACHE_EXIT, "shrink_cache_exit", \
	       "zone", \
	       "scan control", \
	       "scanned pages", \
	       NULL)
LKST_ETYPE_DEF(0x0c6, NORMAL, PAGE_AGING_ENTER, "page_aging_enter", \
	       "zone", \
	       "scan control", \
	       "max_scan", \
	       NULL)
LKST_ETYPE_DEF(0x0c7, NORMAL, PAGE_AGING_EXIT, "page_aging_exit", \
	       "zone", \
	       "scan control", \
	       "nr scanned page", \
	       "nr moved page")
LKST_ETYPE_DEF(0x0c8, NORMAL, PAGE_RECLAIM_ENTER, "page_reclaim_enter", \
	       "gfp_mask", \
	       "order", \
	       "zone", \
	       NULL)
LKST_ETYPE_DEF(0x0c9, NORMAL, PAGE_RECLAIM_EXIT, "page_reclaim_exit", \
	       "gfp_mask", \
	       "order", \
	       "zone", \
	       "reclaimed pages")

LKST_ETYPE_DEF(0x0d0, NORMAL, BUFFER_SUBMIT_BH, "submit buffer_head", \
	       "buffer_head bh", \
	       "mapped page", \
	       "rw", \
	       "bh size")
LKST_ETYPE_DEF(0x0d1, INLINE, BUFFER_ENDIO_BH, "end buffer_head io", \
	       "buffer_head bh", \
	       "mapped page", \
	       "retval", \
	       "done size")
LKST_ETYPE_DEF(0x0d2, NORMAL, BIO_MAKE_REQ, "generic_make_request", \
	       "bio", \
	       "request_queue", \
	       "rw", \
	       "device")
LKST_ETYPE_DEF(0x0d3, INLINE, BIO_END_IO, "bio_endio", \
	       "bio", \
	       "bytes_done", \
	       NULL, \
	       "device")
LKST_ETYPE_DEF(0x0d4, NORMAL, BLK_GET_REQ, "block get_request", \
	       "request_queue", \
	       "rw", \
	       "request queue length", \
	       "request")
LKST_ETYPE_DEF(0x0d5, NORMAL, BLK_PUT_REQ, "block put_request", \
	       "request_queue", \
	       "rw", \
	       "request queue length", \
	       "freed request")

LKST_ETYPE_DEF(0x0e0, NORMAL, NET_V4RTIN_ENTER, "ip_route_input enter", \
	       "skb", \
	       "flowi", \
	       "daddr", \
	       "saddr")
LKST_ETYPE_DEF(0x0e1, NORMAL, NET_V4RTIN_EXIT, "ip_route_input exit", \
	       "skb", \
	       "flowi", \
	       "error", \
	       NULL)
LKST_ETYPE_DEF(0x0e2, NORMAL, NET_V4RTOUT_ENTER, "ip_route_output enter", \
	       "rtable", \
	       "flowi", \
	       "daddr", \
	       "saddr")
LKST_ETYPE_DEF(0x0e3, NORMAL, NET_V4RTOUT_EXIT, "ip_route_output exit", \
	       "rtable", \
	       "flowi", \
	       "error", \
	       NULL)
LKST_ETYPE_DEF(0x0e4, NORMAL, NET_START_XMIT, "hard_start_xmit", \
	       "skb", \
	       "dev", \
	       "error", \
	       NULL)

//0xF00 event
LKST_ETYPE_DEF(0xF00, INLINE, LKST_INIT, "lkst_init", \
	"data", \
	NULL, \
	NULL, \
	NULL)

//0xF01 event
LKST_ETYPE_DEF(0xF01, UNDEF, LKST_KERNEL_DUMP, "lkst_kernel_dump", \
	"dump state", \
	"dump device", \
	NULL, \
	NULL)

//0xF08 event
LKST_ETYPE_DEF(0xF08, INLINE, LKST_MSET_XCHG, "lkst_mset_xchg", \
	"old_id/new_id", \
	"old_maskset", \
	"new_maskset", \
	NULL)

//0xF10 event
LKST_ETYPE_DEF(0xF10, INLINE, LKST_BUFF_SHIFT, "lkst_buff_shift", \
	"buffer", \
	"next_buffer", \
	NULL, \
	NULL)

//0xF11 event
LKST_ETYPE_DEF(0xF11, INLINE, LKST_BUFF_OVFLOW, "lkst_buff_ovflow", \
	NULL, \
	NULL, \
	NULL, \
	NULL)

//0xF12 event
LKST_ETYPE_DEF(0xF12, UNDEF, LKST_BUFF_HIGH, "lkst_buff_high", \
	NULL, \
	NULL, \
	NULL, \
	NULL)

#ifndef CONFIG_X86_4G
//0xF18 event
LKST_ETYPE_DEF(0xF18, UNDEF, LKST_SYNC_TIME, "lkst_sync_time", \
	NULL, \
	NULL, \
	NULL, \
	NULL)
#endif

//0xFFC event
LKST_ETYPE_DEF(0xFFC, UNDEF, LKST_EXTEND, "lkst_extend_event", \
	"extend arg1", \
	"extend arg2", \
	"extend arg3", \
	"extend arg4")

//0xFFD event
LKST_ETYPE_DEF(0xFFD, UNDEF, LKST_EXTENDE, "lkst_extend_event_end", \
	"extend arg1", \
	"extend arg2", \
	"extend arg3", \
	"extend arg4")

//0xFFE event
LKST_ETYPE_DEF(0xFFE, UNDEF, LKST_OVWRTN_REC, "overwritten_detected", \
	NULL, \
	NULL, \
	NULL, \
	NULL)

//0xFFF event
LKST_ETYPE_DEF(0xFFF, UNDEF, LKST_ETYPE_MAX, "LKST_ETYPE_MAX", \
	NULL, \
	NULL, \
	NULL, \
	NULL)

/* arch specific events */
#include <asm/lkst_etype.h>

#ifdef LKST_ETYPE_DEF_NOT_DEFINED
#undef LKST_ETYPE_DEF_NOT_DEFINED
#undef LKST_ETYPE_DEF
#endif
